<?php


namespace Cms\Model\Contract\Config;

use Cms\Model\AbstractConfigModel;

/**
 * Class ConfigLienReservationModel
 * @package Cms\Model\Contract\Config
 * @property bool $follow_link
 * @property string $url
 */
class ConfigLienReservationModel extends AbstractConfigModel
{
    //<editor-fold desc="propriété pour Product">
    /** @var  bool */
    protected $follow_link;
    //</editor-fold>

    //<editor-fold desc="propriété pour ProductConfig">
    /** @var  string */
    protected $url;
    //</editor-fold>

    /** @var string */
    protected $type;

    /** @var string */
    protected $high_season_price;

    /** @var string */
    protected $integration_widget;

    /** @var string */
    protected $price_duration;
}
